/* eslint-disable @next/next/no-img-element */

import { parseJsonString } from '../utils';
import { getImageType, getUrlBasedOnDerivative } from '../utils/bynder-util';

type BynderImageProps = {
    imageText: string;
    suffix?: string;
    className?: string;
    testId?: string;
};

export const BynderImage = ({ imageText = '', suffix, className, testId }: BynderImageProps) => {
    const imageJson = parseJsonString(imageText);
    const image = imageJson?.image?.[0] || {};
    const { databaseId, files, name, selected } = image;
    const { url, fit, position, altText = '', bgColor } = selected ?? {};
    const imageDerivativeType = getImageType(url, databaseId, name, files);
    let imageUrl = getUrlBasedOnDerivative(url, imageDerivativeType, suffix ?? '');
    return (
        <img
            data-testid={testId || 'test-bynder-image'}
            className={`${className || ''} bynder-image`}
            src={imageUrl}
            alt={altText}
            style={{ backgroundColor: bgColor, objectFit: fit, objectPosition: position }}
        />
    );
};
